<!-- markdownlint-disable -->

<a href="https://github.com/qtstrap/qtstrap/blob/master\qtstrap\extras\log_monitor\__init__.py#L0"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

# <kbd>module</kbd> `extras.log_monitor`




**Global Variables**
---------------
- **log_filter_controls**
- **log_profile**
- **log_database_handler**
- **log_table_view**
- **log_widget**
- **db_path**
- **exception_logger_name**

---

<a href="https://github.com/qtstrap/qtstrap/blob/master\qtstrap\extras\log_monitor\__init__.py#L16"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

## <kbd>function</kbd> `install`

```python
install(database_name='P:/qtstrap/qtstrap/log.db', install_excepthook=True)
```








---

_This file was automatically generated via [lazydocs](https://github.com/ml-tooling/lazydocs)._
